class BaseLocationField(object):
    def __init__(self, **kwargs):
        self._based_fields = kwargs.pop('based_fields', [])
        self._zoom = kwargs.pop('zoom', 2)
        self._default = kwargs.pop('default', None)

        self.default = self._default

    def formfield(self, **kwargs):
        return super(BaseLocationField, self).formfield(
            form_class=self.formfield_class,
            based_fields=self._based_fields,
            zoom=self._zoom,
            default=self._default,
            **kwargs)



from setuptools import setup, find_packages


VERSION = __import__('location_field').__version__


setup(
    name='django-location-field',
    version=VERSION,
    description="Location field for Django",
    long_description="This module provides a location field for Django applications.",
    author="Caio Ariede",
    author_email="caio.ariede@gmail.com",
    url="http://github.com/caioariede/django-location-field",
    license="MIT",
    platforms=["any"],
    packages=find_packages(),
    package_data={'location_field': [
        'static/location_field/js/*',
        'templates/location_field/*',
    ]},
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Framework :: Django",
    ],
    include_package_data=True,
    install_requires=[
        'Django>=1.6,<1.9',
        'six',
    ],
)
